=======
History
=======

0.3.1 (2019-12-01)
------------------

* Fixing conversion of very large numbers with decimals to words.


0.3.0 (2019-12-01)
------------------

* Fixing conversion of very large numbers to words.
* Fixing conversion of teens when number is greater than 100 in English.
* Flake8 clean ups


0.2.1 (2019-09-17)
------------------

* Fixing package Manifest to include lang submodule.


0.2.0 (2018-05-15)
------------------

* Adding multilingual support, Swahili and English.


0.1.0 (2018-05-10)
------------------

* Package created.
